/**
*	@file SensorCommunicationLib.cpp
*	@brief contains the SensorCommunicationLib class mathods implementation. This class can be used to ease
*	the programming of an Arduino sketch read data from sensors and transmit them as a stream of csv data. 
*
*	@author	Antonio Cafiero
*
*	@date 11/10/2019
*/


/*
 Copyright 2019, Toni Cafiero, IoThingsWare 
 MIT License terms detailed in LICENSE.txt 
*/
#include <Arduino.h>
#include "SensorCommunicationLib.h"


//Serial data variables
const char kDelimiter = ',';
const int kSerialInterval = 50;
unsigned long serialPreviousTime;


/**
*	This method is the constructor of the SensorCommunicationLib
*	@author	Antonio Cafiero
*	@param NumberOfSensors The number of sensors value to transmitt as a stream of csv
*	@date 11/10/2019
*/ 
SensorCommunicationLib::SensorCommunicationLib(int NumberOfSensors)
{
	kNumberOfSensors=NumberOfSensors;
} 
 
void SensorCommunicationLib::Send()
{
  int i;
  for(i = 0; i < kNumberOfSensors-1; i++){
      Serial.printf("%.2f", Sensors[i]);
      Serial.print(kDelimiter);
  }
  Serial.printf("%.2f", Sensors[i]);
  Serial.println();
}

void SensorCommunicationLib::Tentative()
{
  if((millis() - serialPreviousTime) > kSerialInterval) 
  {
    serialPreviousTime = millis();
    Send(); 
  }
}

/**
*	This method is the constructor of the SensorCommunicationLib
*	@author	Antonio Cafiero
*	@param getSensorData The pointer of the callback routine fo sensors data reading.
*	@date 11/10/2019
*/ 
void SensorCommunicationLib::processSensors(void (*getSensorData)()) //call in loop()
{
	(*getSensorData)();
	delay(10);
	Tentative();
}
